@@ -63,25 +63,24 @@ from dulwich.objects import Blob, Tree
 from dulwich.pack import SHA1Writer
 import dulwich.repo
 
-DEFAULT_ENCODING = 'utf-8'
+DEFAULT_ENCODING = "utf-8"
 
 
 logger = logging.getLogger(__name__)
 
 
 class RepoCollectionMetadata(CollectionMetadata):
-
     def __init__(self, repo):
         self._repo = repo
 
     @classmethod
     def present(cls, repo):
         config = repo.get_config()
-        return config.has_section((b'xandikos', ))
+        return config.has_section((b"xandikos",))
 
     def get_source_url(self):
         config = self._repo.get_config()
-        url = config.get(b'xandikos', b'source')
+        url = config.get(b"xandikos", b"source")
         if not url:
             raise KeyError
         return url.decode(DEFAULT_ENCODING)
@@ -89,54 +88,55 @@ class RepoCollectionMetadata(CollectionMetadata):
     def set_source_url(self, url):
         config = self._repo.get_config()
         if url is not None:
-            config.set(
-                b'xandikos', b'source', url.encode(DEFAULT_ENCODING))
+            config.set(b"xandikos", b"source", url.encode(DEFAULT_ENCODING))
         else:
             # TODO(jelmer): Add and use config.remove()
-            config.set(b'xandikos', b'source', b'')
+            config.set(b"xandikos", b"source", b"")
         self._write_config(config)
 
     def get_color(self):
         config = self._repo.get_config()
-        color = config.get(b'xandikos', b'color')
-        if color == b'':
+        color = config.get(b"xandikos", b"color")
+        if color == b"":
             raise KeyError
         return color.decode(DEFAULT_ENCODING)
 
     def set_color(self, color):
         config = self._repo.get_config()
         if color is not None:
-            config.set(
-                b'xandikos', b'color', color.encode(DEFAULT_ENCODING))
+            config.set(b"xandikos", b"color", color.encode(DEFAULT_ENCODING))
         else:
             # TODO(jelmer): Add and use config.remove()
-            config.set(b'xandikos', b'color', b'')
+            config.set(b"xandikos", b"color", b"")
         self._write_config(config)
 
     def _write_config(self, config):
         f = BytesIO()
         config.write_to_file(f)
-        self._repo._put_named_file('config', f.getvalue())
+        self._repo._put_named_file("config", f.getvalue())
 
     def get_displayname(self):
         config = self._repo.get_config()
-        displayname = config.get(b'xandikos', b'displayname')
-        if displayname == b'':
+        displayname = config.get(b"xandikos", b"displayname")
+        if displayname == b"":
             raise KeyError
         return displayname.decode(DEFAULT_ENCODING)
 
     def set_displayname(self, displayname):
         config = self._repo.get_config()
         if displayname is not None:
-            config.set(b'xandikos', b'displayname',
-                       displayname.encode(DEFAULT_ENCODING))
+            config.set(
+                b"xandikos",
+                b"displayname",
+                displayname.encode(DEFAULT_ENCODING),
+            )
         else:
-            config.set(b'xandikos', b'displayname', b'')
+            config.set(b"xandikos", b"displayname", b"")
         self._write_config(config)
 
     def get_description(self):
         desc = self._repo.get_description()
-        if desc in (None, b''):
+        if desc in (None, b""):
             raise KeyError
         return desc.decode(DEFAULT_ENCODING)
 
@@ -144,62 +144,58 @@ class RepoCollectionMetadata(CollectionMetadata):
         if description is not None:
             self._repo.set_description(description.encode(DEFAULT_ENCODING))
         else:
-            self._repo.set_description(b'')
+            self._repo.set_description(b"")
 
     def get_comment(self):
         config = self._repo.get_config()
-        comment = config.get(b'xandikos', b'comment')
-        if comment == b'':
+        comment = config.get(b"xandikos", b"comment")
+        if comment == b"":
             raise KeyError
         return comment.decode(DEFAULT_ENCODING)
 
     def set_comment(self, comment):
         config = self._repo.get_config()
         if comment is not None:
-            config.set(
-                b'xandikos', b'comment', comment.encode(DEFAULT_ENCODING))
+            config.set(b"xandikos", b"comment", comment.encode(DEFAULT_ENCODING))
         else:
             # TODO(jelmer): Add and use config.remove()
-            config.set(b'xandikos', b'comment', b'')
+            config.set(b"xandikos", b"comment", b"")
         self._write_config(config)
 
     def set_type(self, store_type):
         config = self._repo.get_config()
-        config.set(b'xandikos', b'type', store_type.encode(DEFAULT_ENCODING))
+        config.set(b"xandikos", b"type", store_type.encode(DEFAULT_ENCODING))
         self._write_config(config)
 
     def get_type(self):
         config = self._repo.get_config()
-        store_type = config.get(b'xandikos', b'type')
+        store_type = config.get(b"xandikos", b"type")
         store_type = store_type.decode(DEFAULT_ENCODING)
         if store_type not in VALID_STORE_TYPES:
-            logging.warning(
-                'Invalid store type %s set for %r.',
-                store_type, self._repo)
+            logging.warning("Invalid store type %s set for %r.", store_type, self._repo)
         return store_type
 
     def get_order(self):
         config = self._repo.get_config()
-        order = config.get(b'xandikos', b'calendar-order')
-        if order == b'':
+        order = config.get(b"xandikos", b"calendar-order")
+        if order == b"":
             raise KeyError
-        return order.decode('utf-8')
+        return order.decode("utf-8")
 
     def set_order(self, order):
         config = self._repo.get_config()
         if order is None:
-            order = ''
-        config.set(b'xandikos', b'calendar-order', order.encode('utf-8'))
+            order = ""
+        config.set(b"xandikos", b"calendar-order", order.encode("utf-8"))
         self._write_config(config)
 
 
 class locked_index(object):
-
     def __init__(self, path):
         self._path = path
 
     def __enter__(self):
-        self._file = GitFile(self._path, 'wb')
+        self._file = GitFile(self._path, "wb")
         self._index = Index(self._path)
         return self._index
 
@@ -217,11 +213,9 @@ class locked_index(object):
 
 
 class GitStore(Store):
-    """A Store backed by a Git Repository.
-    """
+    """A Store backed by a Git Repository."""
 
-    def __init__(self, repo, ref=b'refs/heads/master',
-                 check_for_duplicate_uids=True):
+    def __init__(self, repo, ref=b"refs/heads/master", check_for_duplicate_uids=True):
         super(GitStore, self).__init__(MemoryIndex())
         self.ref = ref
         self.repo = repo
@@ -243,14 +237,15 @@ class GitStore(Store):
                 pass
             else:
                 if cf is not None:
-                    cp.read_string(b''.join(cf).decode('utf-8'))
+                    cp.read_string(b"".join(cf).decode("utf-8"))
 
             def save_config(cp, message):
                 f = StringIO()
                 cp.write(f)
                 self._import_one(
-                    CONFIG_FILENAME, [f.getvalue().encode('utf-8')],
-                    message)
+                    CONFIG_FILENAME, [f.getvalue().encode("utf-8")], message
+                )
+
             return FileBasedCollectionMetadata(cp, save=save_config)
 
     def __repr__(self):
@@ -279,8 +274,15 @@ class GitStore(Store):
             raise InvalidETag(name, etag, replace_etag)
         return etag
 
-    def import_one(self, name, content_type, data, message=None, author=None,
-                   replace_etag=None):
+    def import_one(
+        self,
+        name,
+        content_type,
+        data,
+        message=None,
+        author=None,
+        replace_etag=None,
+    ):
         """Import a single object.
 
         :param name: name of the object
@@ -297,8 +299,7 @@ class GitStore(Store):
         if content_type is None:
             fi = open_by_extension(data, name, self.extra_file_handlers)
         else:
-            fi = open_by_content_type(
-                data, content_type, self.extra_file_handlers)
+            fi = open_by_content_type(data, content_type, self.extra_file_handlers)
         if name is None:
             name = str(uuid.uuid4())
             extension = MIMETYPES.guess_extension(content_type)
@@ -315,9 +316,9 @@ class GitStore(Store):
                 old_fi = self.get_file(name, content_type, replace_etag)
             except KeyError:
                 old_fi = None
-            message = '\n'.join(fi.describe_delta(name, old_fi))
+            message = "\n".join(fi.describe_delta(name, old_fi))
         etag = self._import_one(name, fi.normalized(), message, author=author)
-        return (name, etag.decode('ascii'))
+        return (name, etag.decode("ascii"))
 
     def _get_raw(self, name, etag=None):
         """Get the raw contents of an object.
@@ -328,28 +329,26 @@ class GitStore(Store):
         """
         if etag is None:
             etag = self._get_etag(name)
-        blob = self.repo.object_store[etag.encode('ascii')]
+        blob = self.repo.object_store[etag.encode("ascii")]
         return blob.chunked
 
     def _scan_uids(self):
         removed = set(self._fname_to_uid.keys())
         for (name, mode, sha) in self._iterblobs():
-            etag = sha.decode('ascii')
+            etag = sha.decode("ascii")
             if name in removed:
                 removed.remove(name)
-            if (name in self._fname_to_uid and
-                    self._fname_to_uid[name][0] == etag):
+            if name in self._fname_to_uid and self._fname_to_uid[name][0] == etag:
                 continue
             blob = self.repo.object_store[sha]
-            fi = open_by_extension(blob.chunked, name,
-                                   self.extra_file_handlers)
+            fi = open_by_extension(blob.chunked, name, self.extra_file_handlers)
             try:
                 uid = fi.get_uid()
             except KeyError:
-                logger.warning('No UID found in file %s', name)
+                logger.warning("No UID found in file %s", name)
                 uid = None
             except InvalidFileContents:
-                logging.warning('Unable to parse file %s', name)
+                logging.warning("Unable to parse file %s", name)
                 uid = None
             except NotImplementedError:
                 # This file type doesn't support UIDs
@@ -376,7 +375,7 @@ class GitStore(Store):
             (mime_type, _) = MIMETYPES.guess_type(name)
             if mime_type is None:
                 mime_type = DEFAULT_MIME_TYPE
-            yield (name, mime_type, sha.decode('ascii'))
+            yield (name, mime_type, sha.decode("ascii"))
 
     @classmethod
     def create(cls, path):
@@ -513,13 +512,12 @@ class GitStore(Store):
         if old_ctag is None:
             t = Tree()
             self.repo.object_store.add_object(t)
-            old_ctag = t.id.decode('ascii')
+            old_ctag = t.id.decode("ascii")
         previous = {
             name: (content_type, etag)
             for (name, content_type, etag) in self.iter_with_etag(old_ctag)
         }
-        for (name, new_content_type, new_etag) in (
-                self.iter_with_etag(new_ctag)):
+        for (name, new_content_type, new_etag) in self.iter_with_etag(new_ctag):
             try:
                 (old_content_type, old_etag) = previous[name]
             except KeyError:
@@ -554,17 +552,17 @@ class BareGitStore(GitStore):
     def _get_etag(self, name):
         tree = self._get_current_tree()
         name = name.encode(DEFAULT_ENCODING)
-        return tree[name][1].decode('ascii')
+        return tree[name][1].decode("ascii")
 
     def get_ctag(self):
         """Return the ctag for this store."""
-        return self._get_current_tree().id.decode('ascii')
+        return self._get_current_tree().id.decode("ascii")
 
     def _iterblobs(self, ctag=None):
         if ctag is None:
             tree = self._get_current_tree()
         else:
-            tree = self.repo.object_store[ctag.encode('ascii')]
+            tree = self.repo.object_store[ctag.encode("ascii")]
         for (name, mode, sha) in tree.iteritems():
             name = name.decode(DEFAULT_ENCODING)
             if name == CONFIG_FILENAME:
@@ -580,8 +578,9 @@ class BareGitStore(GitStore):
         return cls(dulwich.repo.MemoryRepo())
 
     def _commit_tree(self, tree_id, message, author=None):
-        return self.repo.do_commit(message=message, tree=tree_id, ref=self.ref,
-                                   author=author)
+        return self.repo.do_commit(
+            message=message, tree=tree_id, ref=self.ref, author=author
+        )
 
     def _import_one(self, name, data, message, author=None):
         """Import a single object.
@@ -598,10 +597,9 @@ class BareGitStore(GitStore):
         old_tree_id = tree.id
         name_enc = name.encode(DEFAULT_ENCODING)
         tree[name_enc] = (0o644 | stat.S_IFREG, b.id)
-        self.repo.object_store.add_objects([(tree, ''), (b, name_enc)])
+        self.repo.object_store.add_objects([(tree, ""), (b, name_enc)])
         if tree.id != old_tree_id:
-            self._commit_tree(tree.id, message.encode(DEFAULT_ENCODING),
-                              author=author)
+            self._commit_tree(tree.id, message.encode(DEFAULT_ENCODING), author=author)
         return b.id
 
     def delete_one(self, name, message=None, author=None, etag=None):
@@ -620,17 +618,18 @@ class BareGitStore(GitStore):
             current_sha = tree[name_enc][1]
         except KeyError:
             raise NoSuchItem(name)
-        if etag is not None and current_sha != etag.encode('ascii'):
-            raise InvalidETag(name, etag, current_sha.decode('ascii'))
+        if etag is not None and current_sha != etag.encode("ascii"):
+            raise InvalidETag(name, etag, current_sha.decode("ascii"))
         del tree[name_enc]
-        self.repo.object_store.add_objects([(tree, '')])
+        self.repo.object_store.add_objects([(tree, "")])
         if message is None:
             fi = open_by_extension(
-                self.repo.object_store[current_sha].chunked, name,
-                self.extra_file_handlers)
+                self.repo.object_store[current_sha].chunked,
+                name,
+                self.extra_file_handlers,
+            )
             message = "Delete " + fi.describe(name)
-        self._commit_tree(tree.id, message.encode(DEFAULT_ENCODING),
-                          author=author)
+        self._commit_tree(tree.id, message.encode(DEFAULT_ENCODING), author=author)
 
     @classmethod
     def create(cls, path):
@@ -666,7 +665,7 @@ class TreeGitStore(GitStore):
     def _get_etag(self, name):
         index = self.repo.open_index()
         name = name.encode(DEFAULT_ENCODING)
-        return index[name].sha.decode('ascii')
+        return index[name].sha.decode("ascii")
 
     def _commit_tree(self, index, message, author=None):
         tree = index.commit(self.repo.object_store)
@@ -684,19 +683,19 @@ class TreeGitStore(GitStore):
         try:
             with locked_index(self.repo.index_path()) as index:
                 p = os.path.join(self.repo.path, name)
-                with open(p, 'wb') as f:
+                with open(p, "wb") as f:
                     f.writelines(data)
                 st = os.lstat(p)
-                blob = Blob.from_string(b''.join(data))
+                blob = Blob.from_string(b"".join(data))
                 encoded_name = name.encode(DEFAULT_ENCODING)
-                if (encoded_name not in index or
-                        blob.id != index[encoded_name].sha):
+                if encoded_name not in index or blob.id != index[encoded_name].sha:
                     self.repo.object_store.add_object(blob)
                     index[encoded_name] = IndexEntry(
-                        *index_entry_from_stat(st, blob.id, 0))
+                        *index_entry_from_stat(st, blob.id, 0)
+                    )
                     self._commit_tree(
-                        index, message.encode(DEFAULT_ENCODING),
-                        author=author)
+                        index, message.encode(DEFAULT_ENCODING), author=author
+                    )
                 return blob.id
         except OSError as e:
             if e.errno == errno.ENOSPC:
@@ -715,32 +714,32 @@ class TreeGitStore(GitStore):
         """
         p = os.path.join(self.repo.path, name)
         try:
-            with open(p, 'rb') as f:
+            with open(p, "rb") as f:
                 current_blob = Blob.from_string(f.read())
         except IOError:
             raise NoSuchItem(name)
         if message is None:
-            fi = open_by_extension(current_blob.chunked, name,
-                                   self.extra_file_handlers)
-            message = 'Delete ' + fi.describe(name)
+            fi = open_by_extension(current_blob.chunked, name, self.extra_file_handlers)
+            message = "Delete " + fi.describe(name)
         if etag is not None:
-            with open(p, 'rb') as f:
+            with open(p, "rb") as f:
                 current_etag = current_blob.id
-            if etag.encode('ascii') != current_etag:
-                raise InvalidETag(name, etag, current_etag.decode('ascii'))
+            if etag.encode("ascii") != current_etag:
+                raise InvalidETag(name, etag, current_etag.decode("ascii"))
         try:
             with locked_index(self.repo.index_path()) as index:
                 os.unlink(p)
                 del index[name.encode(DEFAULT_ENCODING)]
-                self._commit_tree(index, message.encode(DEFAULT_ENCODING),
-                                  author=author)
+                self._commit_tree(
+                    index, message.encode(DEFAULT_ENCODING), author=author
+                )
         except FileLocked:
-            raise LockeError(name)
+            raise LockedError(name)
 
     def get_ctag(self):
         """Return the ctag for this store."""
         index = self.repo.open_index()
-        return index.commit(self.repo.object_store).decode('ascii')
+        return index.commit(self.repo.object_store).decode("ascii")
 
     def _iterblobs(self, ctag=None):
         """Iterate over all items in the store with etag.
@@ -748,7 +747,7 @@ class TreeGitStore(GitStore):
         :yield: (name, etag) tuples
         """
         if ctag is not None:
-            tree = self.repo.object_store[ctag.encode('ascii')]
+            tree = self.repo.object_store[ctag.encode("ascii")]
             for (name, mode, sha) in tree.iteritems():
                 name = name.decode(DEFAULT_ENCODING)
                 if name == CONFIG_FILENAME:
